@@ -22,17 +22,12 @@
  */
 #include "lft_lib.h"
 
-/* BEGIN Added by Roy T. to improve DNS speed/reliability */
-#include <resolv.h>
-extern struct __res_state _res;
-/* END Added by Roy T. to improve DNS speed/reliability */
-
 #if 0
 static char def_payload[] = "\0\0\0\0\0\0\0\0\0\0"; /* default payload for UDP packets */
 #endif
 
-const char *version = "3.8";  		/* set version string */
-static const char *version_date = "(04/2018)";	/* date of this version */
+const char *version = "3.31";  		/* set version string */
+const char *version_date = "(03/2011)";	/* date of this version */
 
 static void
 usage(lft_session_params * sess, char *prog)
@@ -80,11 +75,8 @@ usage(lft_session_params * sess, char *prog)
              "  -U               Display all times in UTC (GMT0).  Activates -T option automatically\n"
              "  -S               Disable the status bar (only show the completed trace)\n"
              "  -V               Display verbose/debug output.  Use more \'V\'s for additional detail\n"
-             "  -x               XML output\n"  
-             "  -g               GraphViz output\n"  
-             "  -G <icons path>  Enable GraphViz output and override path to icons\n"
-             "  -y               Test destination upstream transition hop\n"
              "  -v               Display LFT's version information and exit\n"  
+             "  -x               XML output\n"  
              "\n"
              "Default is: %s -s %d -d %d -m %d -M %d -a %d -c %.0f -t %d -H %d \n\n",
              prog, prog, sess->sport, sess->dport, sess->retry_min, sess->retry_max, sess->ahead_limit,
@@ -156,29 +148,11 @@ main (int argc, char **argv)
     wVersionRequested = MAKEWORD( 2, 2 );
     WSAStartup( wVersionRequested, &wsaData );
 #endif
-
-    /* BEGIN Added by Roy T. to improve DNS speed/reliability */
-    res_init();
-    _res.retrans = 1;
-    _res.retry = 1;
-    /* END Added by Roy T. to improve DNS speed/reliability */
-
+    
     sess = LFTSessionOpen();
     setbuf(stdout, NULL);
-
-    gettimeofday (&tb, NULL);
-    /* eventually this might want to use /dev/urandom or
-        * something on machines that have it.  otherwise,
-        * this does a fairly decent job of using the system
-        * clock.
-        *
-        * multiply tv_usec (range 0-1000000) to be in range 0-2^31,
-        * and xor to randomize the high bits of tv_sec that don't
-        * change very much.
-        */
-    srand(tb.tv_sec ^ (tb.tv_usec * 2147));
     
-    while ((ch = getopt(argc, argv, "Aa:bCc:D:d:EeFf:H:hIiL:l:M:m:NnPpq:RrSs:Tt:UuVvxw:zgG:y")) != EOF)
+    while ((ch = getopt(argc, argv, "Aa:bCc:D:d:EeFf:H:hIiL:l:M:m:NnPpq:RrSs:Tt:UuVvxw:z")) != EOF)
         switch (ch) {
             case 'f':
                 LFTSetupSendDevice(sess, optarg);
@@ -298,19 +272,9 @@ main (int argc, char **argv)
                 /* Yes, this is a ridiculous randomizer, but it's adequate */
                 sess->sport = rand()%32525+32525;
                 break;
-            case 'x':
-                setOutputStyle(1);
-                break;
-            case 'g':
-                setOutputStyle(2);
-                break;
-            case 'G':
-                setOutputStyle(2);
-				sess->graphviz_icon_path=optarg;
-                break;
-            case 'y':
-                sess->check_seam=1;
-                break;
+	     case 'x':
+		setOutputStyle(1);
+		break;
             default:
                 usage(sess, argv[0]);
         }
@@ -318,16 +282,27 @@ main (int argc, char **argv)
     if((argc - optind) < 1)
 	usage(sess, argv[0]);
         
-    if (sess->noisy && !outputStyleIsXML() && !outputStyleIsGraphViz())
+    if (sess->noisy && !outputStyleIsXML())
         printf ("Layer Four Traceroute (LFT) version %s", version);
-    if (sess->noisy > 1 && !outputStyleIsXML() && !outputStyleIsGraphViz()) 
+    if (sess->noisy > 1 && !outputStyleIsXML()) 
         printf (" ... (verbosity level %d)",sess->noisy);
-    if (sess->noisy && !outputStyleIsXML() && !outputStyleIsGraphViz())    
+    if (sess->noisy && !outputStyleIsXML())    
         printf ("\n");
 	if(outputStyleIsXML())
 	{
 		printf("<lft verbositylevel=\"%d\">\n",sess->noisy);
 	}
+    gettimeofday (&tb, NULL);
+    /* eventually this might want to use /dev/urandom or
+        * something on machines that have it.  otherwise,
+        * this does a fairly decent job of using the system
+        * clock.
+        *
+        * multiply tv_usec (range 0-1000000) to be in range 0-2^31,
+        * and xor to randomize the high bits of tv_sec that don't
+        * change very much.
+        */
+    srand(tb.tv_sec ^ (tb.tv_usec * 2147));
     
     sess->hostname = argv[optind++];
     sess->hostname_lsrr_size = 0;
@@ -340,9 +315,7 @@ main (int argc, char **argv)
 				printf("</lft>\n");
 			}
 			else
-			{
 				fprintf(stderr, "LFT: Too many LSRR hosts - maximum is 8\n");
-			}
             exit(EXIT_FAILURE);
         }
     }
@@ -363,10 +336,8 @@ main (int argc, char **argv)
 					if(outputStyleIsXML())
 						printf("<warning>Starting UDP port %d is too high.  Will start with %d instead.</warning>",sess->dport, (65535 - sess->ttl_limit));
 					else
-					{
 						fprintf (stderr,
-								 "LFT warning: Starting UDP port %d is too high.  Will start with %d instead.\n", sess->dport, (65535 - sess->ttl_limit));
-					}
+                             "LFT warning: Starting UDP port %d is too high.  Will start with %d instead.\n", sess->dport, (65535 - sess->ttl_limit));
                 }
             }
             sess->auto_ports = 0;
